Add possible values to an integer or a character feature property in KMR
add_property_values(kmr, feature, property, values)The modified KMR MDB object
a KMR object
the name of the feature type
the name of the property
a vector of character or integer or a named vector with the description of the values