Wraps each input sub-query as a derived table and combines them with
UNION DISTINCT or UNION ALL. A single sub-query is returned wrapped but
without any UNION clause.
Usage
ch_union_query(queries, mode = c("DISTINCT", "ALL"))Wraps each input sub-query as a derived table and combines them with
UNION DISTINCT or UNION ALL. A single sub-query is returned wrapped but
without any UNION clause.
ch_union_query(queries, mode = c("DISTINCT", "ALL"))