Subset a metaMDB object according to row position in one table
# S3 method for metaMDB
slice(.data, ..., .preserve = FALSE)a memoMDB object
a metaMDB object
a single argument. The name of this argument should be a table name of x and the value of this argument should be vector of integers corresponding to row indexes.
not used