| write_MergeTree | R Documentation |
Write a Clickhouse MergeTree table
write_MergeTree(
con,
dbName,
tableName,
value,
rtypes = NULL,
nullable = NULL,
lowCardinality = NULL,
sortKey = NULL,
indexes = NULL,
projections = NULL,
by = 10^7
)
con |
the clickhouse connection |
dbName |
the name of the database |
tableName |
the name of the table |
value |
the table to import |
rtypes |
a named character vector giving the R type of each and every columns. If NULL (default), types are guessed from value. |
nullable |
a character vector indicating the name of the columns which are nullable (default: NULL) |
lowCardinality |
a character vector indicating the name of the columns with low cardinality (default: NULL) |
sortKey |
a character vector indicating the name of the columns used in the sort key. If NULL (default), all the non-nullable columns are used in the key. |
indexes |
a data.frame with 3 columns:
|
projections |
a data.frame with 3 columns:
|
by |
the size of the batch: number of records to import together (default: 10^7) |
No return value, called for side effects
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.