Write a Clickhouse MergeTree table
write_MergeTree(
con,
dbName,
tableName,
value,
rtypes = NULL,
nullable = NULL,
lowCardinality = NULL,
sortKey = NULL,
indexes = NULL,
projections = NULL,
by = 10^7
)No return value, called for side effects
the clickhouse connection
the name of the database
the name of the table
the table to import
a named character vector giving the R type of each and every columns. If NULL (default), types are guessed from value.
a character vector indicating the name of the columns which are nullable (default: NULL)
a character vector indicating the name of the columns with low cardinality (default: NULL)
a character vector indicating the name of the columns used in the sort key. If NULL (default), all the non-nullable columns are used in the key.
a data.frame with 3 columns:
idx: index name,
field: field name,
type: 'bloom_filter(0.01)', 'minmax'... (see https://clickhouse.com/docs/optimize/skipping-indexes)
granularity: index granularity
a data.frame with 3 columns:
projection: projection name (e.g., "prj_tn_cn"),
select: select statement (e.g., "SELECT *"),
clause: clause for the projection (e.g., "ORDER BY (cn)")
the size of the batch: number of records to import together (default: 10^7)